#
# spec file for package fbreader
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define         zl_sover 0_99
Name:           fbreader
Version:        0.99.4
Release:        3.30
Summary:        E-book reader
License:        GPL-2.0+
Group:          Productivity/Other
Url:            http://www.fbreader.org/
Source0:        %{name}-sources-%{version}.tgz
Source1:        FBReader.desktop
Source3:        fbreader.xml
# PATCH-FIX-UPSTREAM to prevent crash with zipped fb2 files.
# See https://github.com/geometer/FBReader/issues/232 for more info
Patch0:         FBReader-0.99.4-fix-crash-with-fb2.zip-files.patch
# PATCH-FIX-OPENSUSE to workaround for build issue via gcc6,
# see more at https://github.com/geometer/FBReader/issues/289
Patch1:         fbreader-0.99.4-gcc6-Wno-narrowing.diff
# PATCH-FIX-UPSTREAM https://github.com/geometer/FBReader/pull/295
Patch2:         FBReader-0.99.4-reproducible.patch
# PATCH-FEATURE-OPENSUSE fbreader-0.99.4-qt5.patch to use Qt5 libraries, courtesy of Arch -- aloisio@gmx.com
Patch3:         fbreader-0.99.4-qt5.patch
BuildRequires:  expat
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(enca)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(fribidi)
BuildRequires:  pkgconfig(libcurl) >= 7.17
BuildRequires:  pkgconfig(libunibreak)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(zlib)

%description
A multi-platform ebook reader which supports popular ebook formats:
ePub, fb2, mobi, rtf, html, plain text, and a lot of other formats.
It provides access to popular network libraries that contain a large
set of ebooks. Download books for free or for a fee. Add your own
catalog. Highly customizable. Choose colors, fonts, page turning
animations, dictionaries, bookmarks, etc. to make reading as
convenient as you want.

%package -n     zlibrary%{zl_sover}
Summary:        Cross-platform GUI library
Group:          System/Libraries
Requires:       zlibrary-data >= %{version}
Requires:       zlibrary-ui = %{version}

%description -n zlibrary%{zl_sover}
ZLibrary is a cross-platform library to build applications running on
desktop Linux, Windows, and different Linux-based PDAs.

%package -n zlibrary-data
Summary:        Data files for Zlibrary
Group:          Productivity/Other
BuildArch:      noarch

%description -n zlibrary-data
This package contains data files for Zlibrary.

%package -n     zlibrary-devel
Summary:        Development files for zlibrary
Group:          Development/Libraries/C and C++
Requires:       libzlui%{zl_sover} = %{version}
Requires:       zlibrary%{zl_sover} = %{version}

%description -n zlibrary-devel
This package contains the libraries amd header files that are needed
for writing applications with Zlibrary.

%package -n     libzlui%{zl_sover}
Summary:        Qt5 interface module for ZLibrary
Group:          System/Libraries
Provides:       zlibrary-ui = %{version}
Requires:       zlibrary-data >= %{version}

%description -n libzlui%{zl_sover}
This package provides a Qt5-based UI for ZLibrary.

%prep
%setup -q
%patch0 -p1
%if 0%{?suse_version} >= 1500
%patch1 -p0
%endif
%patch2 -p1
%patch3 -p1

%build
make %{?_smp_mflags} -C zlibrary/core TARGET_ARCH=desktop LIBDIR=%{_libdir} UI_TYPE=dummy
#TARGET_STATUS=debug
make %{?_smp_mflags} -C zlibrary/text TARGET_ARCH=desktop LIBDIR=%{_libdir} UI_TYPE=dummy
make %{?_smp_mflags} -C zlibrary/ui   TARGET_ARCH=desktop LIBDIR=%{_libdir} UI_TYPE=qt4
make %{?_smp_mflags} -C fbreader      TARGET_ARCH=desktop LIBDIR=%{_libdir} UI_TYPE=dummy

%install
make -C zlibrary/core do_install do_install_dev DESTDIR=%{buildroot} TARGET_ARCH=desktop LIBDIR=%{_libdir} UI_TYPE=dummy
make -C zlibrary/text do_install do_install_dev DESTDIR=%{buildroot} TARGET_ARCH=desktop LIBDIR=%{_libdir} UI_TYPE=dummy
make -C zlibrary/ui              do_install     DESTDIR=%{buildroot} TARGET_ARCH=desktop LIBDIR=%{_libdir} UI_TYPE=qt4
make -C fbreader                 do_install     DESTDIR=%{buildroot} TARGET_ARCH=desktop                   UI_TYPE=dummy

# desktop file
mkdir -p %{buildroot}%{_datadir}/applications/
install -m644 %{SOURCE1} %{buildroot}%{_datadir}/applications/FBReader.desktop

# mime type
mkdir -p %{buildroot}%{_datadir}/mime/packages/
install -m644 %{SOURCE3} %{buildroot}%{_datadir}/mime/packages/fbreader.xml

# man page
mkdir -p %{buildroot}%{_mandir}/man1
install -m644 fbreader/desktop/FBReader.1 %{buildroot}%{_mandir}/man1

%fdupes -s %{buildroot}

%if 0%{?suse_version} < 1500
%post
%desktop_database_post

%postun
%desktop_database_postun
%endif

%post   -n zlibrary%{zl_sover} -p /sbin/ldconfig

%postun -n zlibrary%{zl_sover} -p /sbin/ldconfig

%post   -n libzlui%{zl_sover} -p /sbin/ldconfig

%postun -n libzlui%{zl_sover} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc fbreader/LICENSE ChangeLog
%{_bindir}/FBReader
%{_datadir}/FBReader
%{_datadir}/applications/FBReader.desktop
%{_datadir}/mime/packages/fbreader.xml
%{_datadir}/pixmaps/FBReader
%{_datadir}/pixmaps/FBReader.png
%{_mandir}/man1/FBReader.1.gz

%files -n zlibrary%{zl_sover}
%defattr(-,root,root,-)
%doc fbreader/LICENSE
%{_libdir}/libzlcore.so.*
%{_libdir}/libzltext.so.*

%files -n zlibrary-data
%defattr(-,root,root,-)
%{_datadir}/zlibrary/

%files -n zlibrary-devel
%defattr(-,root,root,-)
%{_includedir}/zlibrary/
%{_libdir}/libzlcore.so
%{_libdir}/libzltext.so
%{_libdir}/libzlui.so

%files -n libzlui%{zl_sover}
%defattr(-,root,root,-)
%{_libdir}/libzlui.so.*

%changelog
* Wed Apr  4 2018 aloisio@gmx.com
- Added fbreader-0.99.4-qt5.patch and switched to Qt5 build
- Spec cleanup
* Wed Mar  7 2018 bwiedemann@suse.com
- Add FBReader-0.99.4-reproducible.patch to make build reproducible
  (boo#1041090)
* Thu Jun 23 2016 dap.darkness@gmail.com
- Added fbreader-0.99.4-gcc6-Wno-narrowing.diff as a workaround
  for https://github.com/geometer/FBReader/issues/289
- Added %%%%description tag & noarch for zlibrary-data subpackage.
* Sun Jun 19 2016 dap.darkness@gmail.com
- Removed README.SuSE because there is only Qt GUI now.
- pkgconfig().
* Sun Jun 19 2016 jengelh@inai.de
- Fixup shared library packaging
* Sun May 25 2014 trcs@gmx.com
- Update to version 0.99.4
  * Fixed bug with freezing at start
  * List of network libraries is updated now from fbreader.org
  * Fixed working with secured connections (now authentification and books buying on LitRes.ru catalog works)
  * Image support for Ms-Word doc format
  * Esperanto interface localization has been added (by Katarína Nosková)
  * Hyphenation patterns for Polish (by Tomasz Długosz)
  * Polish interface localization (by Tomasz Długosz)
  * Speed of library scanning has been increased
  * Plugin for reading MsWord (*.doc) books
  * Fixed zip reading for several ePub books (e.g. for "die Zeit" ePubs)
  * Support for book series in ePubs with point format (e.g. "2.5") has been added
  * Fixed image support in RTF books
  * Encoding & language recognizing has been improved
  * As from version 0.99.0 FBReader for Linux supports qt4 interface only
  * Chinese text drawing optimization (thanks to You Sheng (SmartDevices) for idea)
  * Mobipocket image processing has been fixed
  * Standard file open dialog is now used instead of the old specially written for FBReader
  * CSS processing for multi-xhtml epubs has been fixed (in 0.12.* the CSS loaded for the first xhtml was also applied for all other xhtmls)
  * Chinese encodings detection has been improved
  * Language/encoding detection for small files has been improved
  * A problem with TOC in newest O'Reilly ePubs has been fixed
  * A detection of book format by mime-type (not by file extension) has been partially implemented (in Gtk+ version only)
  * Polish interface localization has been added (by Rafał Bakuła)
- Updated FBReader.desktop
- Cleaned spec file
  * Removed GTK UI version build because it's broken an isn't supported anymore
    See https://github.com/geometer/FBReader/issues/222 and the above changelog
- Dropped unneeded fbreader-0.12.10-c++.patch
- Added FBReader-0.99.4-fix-crash-with-fb2.zip-files.patch
  * fixes crashes with fb2.zip files
* Tue Oct 16 2012 coolo@suse.com
- add explicit buildrequire on libbz2-devel
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sun Sep 18 2011 jengelh@medozas.de
- Apply packaging guidelines (remove redundant/obsolete
  tags/sections from specfile, etc.)
* Wed Aug 31 2011 kirill.kirillov@gmail.com
- cleaned spec using spec-cleaner
- fixed generic-name-not-in-filelist RPMLINT warning
* Tue Aug 23 2011 kirill.kirillov@gmail.com
- split zlibrary and zlibrary-ui packages (based on Fedora spec)
- used alternatives to select user interface (based of Fedora spec)
* Fri Dec 31 2010 kirill.kirillov@gmail.com
- added mime support (fbreader.xml)
* Tue Aug 17 2010 kirill.kirillov@gmail.com
- added fbreader-0.12.10-c++.patch to fix compilation (from archlinux)
* Tue Aug 17 2010 kirill.kirillov@gmail.com
- Update to 0.12.10
  + Processing of external hyperlinks in ePub files has been changed.
- Changes for 0.12.9
  + Processing of epub local hyperlinks of form ../dir/file.html has been fixed.
  + Code is now compilable with gcc 4.4.* (missing include directives have been added).
- Changes for 0.12.8
  + Smashwords library support has been improved: purchase links have been added.
  + LitRes library support has been updated: since this version FBReader uses an OPDS proxy located at http://data.fbreader.org/ for most operations with the LitRes catalog.
  + Processing of the xhtml hyperlinks in html encoded form (like /files/This%%20is%%20a%%20link) has been fixed.
  + A seg.fault during scanning several archives has been fixed.
  + Lithuanian localization has been updated.
  + Vietnamese language/encoding detection patterns have been added.
- Changes for 0.12.7
  + Vietnamese interface taranslation by Phạm Văn Hùng_Firestork has been added.
  + LitRes integration broken in the previous version has been fixed.
- Changes for 0.12.6
  + The viewing of ePub files from fictionwise.com has been fixed. A set of files from this site are compressed with some errors. However other readers (like Adobe Digital Editions) allows to read these books. FBReader 0.12.6 supports such books too.
* Sat Jan 16 2010 Kirill Kirillov <kirill.kirillov@gmail.com>
- Update to 0.12.1
  + Integration with LitRes.ru has been improved. A link for signing up has been added. A browsing by authors and by genres has been added.
  + Scrolling preferences have been simplified. Tap scrolling has been fixed.
  + Lithuanian localization has been added (thanks to Stanislovas Zacharovas).
  + Open file dialog behaviour has been fixed (in Gtk+ version).
  + A crach on some mobipocket files has been fixed.
* Thu Dec 10 2009 Kirill Kirillov <kirill.kirillov@gmail.com>
- Update to 0.12.0
  + New presentation of library.
  + Better integration with network libraries: FeedBooks, LitRes,
    Shucang and SmashWords. This version allows to browse catalogs,
    to search and download the books. For LitRes (Russian e-library)
    it is also possible to purchase books.
  + Added Chinese localization (by Shucang).
  + Image scaling has been implemented.
  + Better encoding/language detection. Arabic and Indonesian patterns are back.
  + Mobipocket, eReader and chm support have been improved.
* Sun Apr  5 2009 kirill.kirillov@gmail.com
- Update to 0.10.7
  + A conflict between hyperlink clicks and touch scrolling has been fixed
- Changes for 0.10.2
  + A bug with images/css links in epub has been fixed
* Sat Mar 21 2009 kirill.kirillov@gmail.com
- Update to 0.10.5
  + An FBReader freeze has been fixed
  + Several text selection related issues have been fixed
* Thu Mar 19 2009 kirill.kirillov@gmail.com
- Update to 0.10.4
  + Multiple fixes in the epub format support
* Wed Mar  4 2009 kirill.kirillov@gmail.com
- Update to 0.10.3
  + Some issues related to multi-file tar, tar.gz and tar.bz2
    archives have been fixed.
  + Greek hyphenation patterns were regenerated from another
    TeX source.
  + New version has no license issues from the Debian point of view
- Changes for 0.10.2
  + Images order in mobipocket files has been corrected.
  + Indonesian localization files have been updated.
- Changes for 0.10.1
  + Fixed an infinite loop in library building code.
  + Fixed <Space> key processing in qt4-based version.
  + Book description is visible for books found in network libraries.
* Tue Jan 13 2009 lars@linux-schulserver.de
- update to 0.10.0:
  + Network libraries integration has been added. FBReader can
    search and download books from Feedbooks.com and LitRes
    libraries.
  + Partial CSS support for epub files has been added.
    CSS support in html and fb2 is coming soon.
  + Epub and Mobipocket book formats support has been substantially
    improved.
  + Library view usability has been improved: you can now organize
    the tree either by author or by tag.
  + You can now select a word by double-click and a paragraph
    by triple-click.
  + Right-to-left languages and bidirectional texts support has
    been added (GNU FriBidi library is used).
  + Support for Arabic, Hebrew, Greek and Turkish has been added.
  + Czech localization has been added (many thanks to Lubomír Čevela).
  + FBReader now has a new set of icons.
  + It's now possible to use OS scrollbar for navigating through the
    text.
- add fribidi-devel, libcurl-devel, libqt4-devel to BuildRequires
- build gtk and qt4 ports
* Sun Nov 30 2008 lars@linux-schulserver.de
- require libexpat-devel on > 11.0
* Mon Sep 22 2008 lars@linux-schulserver.de
- moved to Education base repository
* Sun Mar 23 2008 kirill.kirillov@gmail.com
- Update to 0.8.17
  + Fixed crash after removing a book from library
  + Updated Finnish interface translation
* Sat Mar 22 2008 kirill.kirillov@gmail.com
- Update to 0.8.16
  + Book tags support has been added
  + The standard Unicode algorithm for line breaking in now used for
  all languages (including Chinese) provided by liblinebreak library
  + Fixed a bug with tapping scrolling/selection
* Mon Mar 17 2008 lars@linux-schulserver.de
- specfile beautify
- fix changelog
- use fdupes
- compress the source tarball
- use %%suse_update_desktopfile macro
- run /sbin/ldconfig
* Mon Mar 10 2008 kirill.kirillov@gmail.com
- Update to 0.8.15
  + Freeze during text scrolling has been fixed.
  + Indonesian localization (by Ketut Putu Kumajaya) has been added.
  + From now FBReader remembers list of recent search patterns.
- Changes for 0.8.14
  + Fixed crash. It was always reproducable for maemo platform and
  was possible for all othr platforms.
- Changes for 0.8.13
  + Freeze on several files has been fixed.
  + Plain text format support has been improved.
  + 'Go to page by number' feature has been added. In desktop version,
  this feature is assigned to 'G' key by default.
* Sun Jan 20 2008 kirill.kirillov@gmail.com
- Update to 0.8.12 bug fix release:
  + #44 "Undo" / "Redo" does not work
  + #73 "Go back" / "Go forward" does not work
  + #74 90%% of Books Loop back to page 3 after page 9/10
* Fri Jan 18 2008 kirill.kirillov@gmail.com
- Update to 0.8.11
  + Tap scrolling is now available for all platforms with touchscreen
  + XML namespace processing has been fixed in formats: oeb, epub, fb2
  + Plain text with UNIX line delimiters problem has been fixed
  + Default settings files are now human-readable
* Thu Jan 10 2008 kirill.kirillov@gmail.com
- Update to 0.8.10
* Sat Sep  1 2007 michel.sylvan@gmail.com
- Strip debugging info into separate subpackage
* Wed Aug 29 2007 michel.sylvan@gmail.com
- Adjust file listing to accomodate changes from previous version
* Wed Aug 29 2007 michel.sylvan@gmail.com
- Add missing BR: on libjpeg-devel (upstream documentation is misleading)
* Wed Aug 29 2007 michel.sylvan@gmail.com
- Update to 0.8.6b
* Sun Jul  1 2007 Wade Berrier <wberrier@gmail.com>
- Update to 0.8.4a
* Sun Jun  3 2007 Wade Berrier <wberrier@gmail.com>
- New package
